import React, { useState, useEffect, useRef } from 'react';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import TypingAnimation from './TypingAnimation';
import { getPromptContent } from '../utils/promptContent';
import { Plus, Send, Upload } from 'lucide-react';
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from './ui/select';

interface ChatInterfaceProps {
  onPromptSelect: (prompt: string, content: any) => void;
  isExpanded: boolean;
  onStartNewChat?: () => void;
}

const prompts = [
  "What can you help me with?",
  "What is MCP?",
  "Who is this for?",
  "Show me how I can earn",
  "Developers",
  "Sample MCPs"
];

const ChatInterface: React.FC<ChatInterfaceProps> = ({ onPromptSelect, isExpanded }) => {
  const [messages, setMessages] = useState<Array<{ text: string; isUser: boolean; isTyping?: boolean }>>([]);
  const [inputValue, setInputValue] = useState('');
  const [isThinking, setIsThinking] = useState(false);
  const [chatKey, setChatKey] = useState(0);
  const [thinkingStage, setThinkingStage] = useState<"thinking" | "memory" | null>(null);
  const scrollAnchorRef = useRef<HTMLDivElement | null>(null);

  const promptPatterns = [
    {
      pattern: /(how|what).*?(help|useful|do|job|use\s+you\s+for|offer|can\s+you\s+do)/i,
      prompt: "What can you help me with?",
    },
    {
      pattern: /(what('| i)?s|define|explain|tell\s+me\s+about).*\b(mcp)\b/i,
      prompt: "What is MCP?",
    },
    {
      pattern: /(who|whom).*?(for|use\s+this|is\s+this\s+platform\s+for|can\s+use)/i,
      prompt: "Who is this for?",
    },
    {
      pattern: /(how|what|can\s+i|is\s+there).*?(earn|moneti[sz]e|money|income|revenue|make\s+money)/i,
      prompt: "Show me how I can earn",
    },
    {
      pattern: /(dev|developers|developed|people)/i,
      prompt: "Developers",
    },
    {
      pattern: /\b(sample|example|show|some)\b.*\b(mcp|mcp server|mcp servers|mcps)\b|\b(mcp|mcp server|mcp servers|mcps)\b.*\b(sample|example|show|some)\b/i,
      prompt: "Sample MCPs",
    },
  ];


  const promptResponses: Record<string, string> = {
    "What can you help me with?": "I can assist you with understanding MCP, exploring features, and showing you how to earn with MCP. Let me show you in a detailed view.",
    "What is MCP?": "MCP stands for Monetizable Code Package. It's a wrapper on an API that works with LLMs, making AI behaviors easy to deploy and monetize. Would you like to see it in a detailed view on the right?",
    "Who is this for?": "MCP is for developers, creators, and businesses who want to build, deploy, and monetize AI-powered code packages easily. Here's a detailed view.",
    "Show me how I can earn": "You can earn by creating MCPs, deploying them, and setting your pricing. Track usage and get paid automatically as others use your MCPs. I have generated a detailed view on the right.",
    "Developers": "A lot of people have put there thoughts and ideas to bring this amazing idea to life. Here on the right I have displayed all the developers who are behind Fastcode.",
    "Sample MCPs": "People all over the world are building MCP servers and earning passively. It's time you start you own as well. Here are some samples for your inspiration."
  };

  const handlePromptClick = (prompt: string, userInput?: string) => {
    setMessages(prev => [...prev, { text: userInput || prompt, isUser: true }]);
    setThinkingStage("thinking");
    setIsThinking(true);

    setTimeout(() => {
      setThinkingStage("memory");
      setTimeout(() => {
        setIsThinking(false);
        setThinkingStage(null);
        setMessages(prev => [
          ...prev,
          {
            text: promptResponses[prompt] || `Let me show you detailed information about "${prompt}"`,
            isUser: false,
            isTyping: true,
          },
        ]);
        setTimeout(() => {
          const content = getPromptContent(prompt);
          onPromptSelect(prompt, content);
        }, 9000);
      }, 1000); // "Activating memory..." duration
    }, 1000); // "Thinking..." duration
  };

  const handleSendMessage = () => {
    if (!inputValue.trim()) return;

    const userMessage = {
      text: inputValue,
      isUser: true,
    };
    setMessages(prev => [...prev, userMessage]);

    const matched = promptPatterns.find(({ pattern }) => pattern.test(inputValue));
    const promptToUse = matched ? matched.prompt : inputValue;

    setInputValue('');
    setThinkingStage("thinking");
    setIsThinking(true);

    setTimeout(() => {
      setThinkingStage("memory");
      setTimeout(() => {
        setIsThinking(false);
        setThinkingStage(null);
        setMessages(prev => [
          ...prev,
          {
            text: promptResponses[promptToUse] || `Let me show you detailed information about "${promptToUse}"`,
            isUser: false,
            isTyping: true,
          },
        ]);
        setTimeout(() => {
          const content = getPromptContent(promptToUse);
          onPromptSelect(promptToUse, content);
        }, 9000);
      }, 1000);
    }, 1000);
  };



  const handleKeyPress = (e: React.KeyboardEvent) => {
    if (e.key === 'Enter') handleSendMessage();
  };


  useEffect(() => {
    const handleLeftSidebarPrompt = (event: CustomEvent) => {
      handlePromptClick(event.detail.prompt);
    };
    window.addEventListener('leftSidebarPrompt' as any, handleLeftSidebarPrompt);
    return () => {
      window.removeEventListener('leftSidebarPrompt' as any, handleLeftSidebarPrompt);
    };
  }, []);

  useEffect(() => {
    scrollAnchorRef.current?.scrollIntoView({ behavior: 'smooth', block:'end' });
  }, [messages]);

  return (
    <div id='chat' className="flex flex-col h-screen max-h-screen overflow-hidden p-6">
      {/* Hero Section */}
      {messages.length === 0 && (
        <div className={`flex-1 flex flex-col justify-center items-center text-center transition-all duration-500 ${
          isExpanded ? 'max-w-4xl mx-auto' : 'max-w-2xl mx-auto'
        }`}>
          <div className="mb-8">
            <h1 className="text-2xl md:text-6xl text-gray-900 dark:text-white mb-6 leading-tight">
              Build an MCP server and become <span className='text-gray-700 dark:text-gray-300'>a part of the new world.</span>
            </h1>
            <p className="text-lg text-gray-600 dark:text-gray-300 mb-8">
              Where AI chatbots are the modern interface.
            </p>
          </div>
          <div className="w-full max-w-2xl p-8 rounded-2xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10">
            <h3 className="text-lg font-medium text-gray-900 dark:text-white mb-6">
              How can I help you today?
            </h3>
            <div className="grid grid-cols-1 md:grid-cols-2 gap-3">
              {prompts.slice(0, 4).map((prompt, index) => (
                <Button
                  key={index}
                  variant="ghost"
                  onClick={() => handlePromptClick(prompt)}
                  className="p-4 h-auto text-left justify-start border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-sm bg-white/5 dark:bg-black/5 hover:bg-white/10 dark:hover:bg-black/10 rounded-xl transition-all duration-300 hover:scale-[1.02]"
                >
                  <span className="text-gray-700 dark:text-gray-300 text-sm">{prompt}</span>
                </Button>
              ))}
            </div>
          </div>
        </div>
      )}

      {/* Chat Messages */}
      {messages.length > 0 && (
        <div className="flex-1 w-full md:w-1/2 mx-auto mb-6 overflow-hidden">
          <div
            className="h-fit overflow-y-auto space-y-4 scrollbar-hide pr-2"
            ref={scrollAnchorRef}
          >
            {messages.map((message, index) => (
              <div
                key={index}
                className={`flex ${message.isUser ? 'justify-end' : 'justify-start'}`}
              >
                <div
                  className={`max-w-xs lg:max-w-md px-4 py-3 rounded-2xl ${
                    message.isUser
                      ? 'dark:bg-gray-100/20 bg-gray-700/20 backdrop-blur-xl text-gray-900 dark:text-white'
                      : 'border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10 text-gray-900 dark:text-white'
                  }`}
                >
                  {message.isTyping ? (
                    <TypingAnimation text={message.text} />
                  ) : (
                    message.text
                  )}
                </div>
              </div>
            ))}
            {/* Status Label */}
            {thinkingStage && (
              <div className="w-full md:w-1/2 mr-auto flex justify-start mb-2 z-30">
                <div className="px-4 py-1 rounded-full bg-gray-900/80 dark:bg-gray-100/80 text-white dark:text-gray-900 text-xs font-semibold shadow transition-all duration-300">
                  {thinkingStage === "thinking" ? "Thinking..." : "Activating memory..."}
                </div>
              </div>
            )}
            {isThinking && (
              <div className="flex justify-start">
                <div className="max-w-xs lg:max-w-md px-4 py-3 rounded-2xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/10 dark:bg-black/10 text-gray-900 dark:text-white">
                  <div className="flex items-center space-x-2">
                    <div className="flex space-x-1">
                      <div className="w-2 h-2 bg-gray-400 rounded-full animate-bounce"></div>
                      <div className="w-2 h-2 bg-gray-400 rounded-full animate-bounce" style={{ animationDelay: '0.1s' }}></div>
                      <div className="w-2 h-2 bg-gray-400 rounded-full animate-bounce" style={{ animationDelay: '0.2s' }}></div>
                    </div>
                    <span className="text-sm">Hmm good question...</span>
                  </div>
                </div>
              </div>
            )}
            {/* Anchor stays inside this container */}
            <div ref={scrollAnchorRef} />
          </div>
        </div>
      )}

      {/* Input Area */}
      <div className="w-full md:w-1/2 mx-auto border border-gray-200 dark:border-gray-700 backdrop-blur-xl bg-white/10 dark:bg-black/10 rounded-2xl px-4 py-3 space-y-3 pointer-events-auto">
        {/* First Line: Text Input */}
        <Input
          value={inputValue}
          onChange={(e) => setInputValue(e.target.value)}
          onKeyUp={(e) => {
            if (e.key === 'Enter' && inputValue.trim()) {
              e.preventDefault();
              handleSendMessage();
            }
          }}
          placeholder="Ask me anything about MCP..."
          className="border-0 bg-transparent focus:outline-none focus:ring-0 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400"
        />

        {/* Second Line: Dropdown + Upload + Send */}
        <div className="flex items-center justify-between pointer-events-auto">
          <div className="flex items-center gap-2">
            {/* Dropdown */}
            <Select>
              <SelectTrigger className="w-[100px] h-9 bg-white/20 dark:bg-black/20 border-0 text-sm text-gray-900 dark:text-white">
                <SelectValue placeholder="GPT-4.1" />
              </SelectTrigger>
              <SelectContent>
                <SelectItem value="one">GPT-4o</SelectItem>
                <SelectItem value="two">o3 Mini</SelectItem>
                <SelectItem value="three">Gemini 2.5 Flash</SelectItem>
              </SelectContent>
            </Select>

            {/* Upload Icon */}
            <Button
              type="button"
              variant="ghost"
              size="icon"
              className="p-2 rounded-full hover:bg-gray-300 dark:hover:bg-gray-700 text-gray-900 dark:text-white"
              aria-label="Upload"
            >
              <Plus className="w-5 h-5" />
            </Button>
          </div>

          {/* Send Button */}
          <Button
            onClick={handleSendMessage}
            disabled={!inputValue.trim()}
            className="h-10 w-10 flex items-center justify-center bg-gray-800 hover:bg-gray-900 dark:bg-gray-700 dark:hover:bg-gray-600 rounded-full text-white disabled:opacity-50 cursor-pointer disabled:cursor-not-allowed"
            aria-label="Send"
          >
            <Send className="w-4 h-4" />
          </Button>
        </div>
      </div>
      // ...existing code...
    </div>
  );
};

export default ChatInterface;
