import { useState, useCallback } from 'react';
import { generateResponse, isQuestionUnknown } from '../services/geminiService';

export interface Message {
  id: string;
  role: 'user' | 'model';
  content: string;
  isUnknown?: boolean;
  timestamp: number;
}

export const useChat = () => {
  const [messages, setMessages] = useState<Message[]>([]);
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);

  const addMessage = useCallback((message: Omit<Message, 'id' | 'timestamp'>) => {
    const newMessage: Message = {
      ...message,
      id: Date.now().toString(),
      timestamp: Date.now(),
    };
    setMessages(prev => [...prev, newMessage]);
    return newMessage;
  }, []);

  const sendMessage = useCallback(async (content: string) => {
    if (!content.trim()) return;

    const userMessage = addMessage({
      role: 'user',
      content,
    });

    setIsLoading(true);
    setError(null);

    try {
      const chatHistory = messages
        .filter(m => m.role === 'user' || m.role === 'model')
        .map(m => ({
          role: m.role,
          parts: m.content,
        }));

      const response = await generateResponse(content, chatHistory);

      if (response.success) {
        const isUnknown = isQuestionUnknown(response.message);
        addMessage({
          role: 'model',
          content: response.message,
          isUnknown,
        });
      } else {
        throw new Error(response.message);
      }
    } catch (err) {
      console.error('Error in sendMessage:', err);
      setError(err instanceof Error ? err.message : 'An unknown error occurred');
      addMessage({
        role: 'model',
        content: 'Sorry, I encountered an error while processing your request. Please try again later.',
        isUnknown: true,
      });
    } finally {
      setIsLoading(false);
    }
  }, [addMessage, messages]);

  const clearChat = useCallback(() => {
    setMessages([]);
    setError(null);
  }, []);

  return {
    messages,
    isLoading,
    error,
    sendMessage,
    clearChat,
  };
};
