import { GoogleGenerativeAI } from '@google/generative-ai';

// Initialize the Gemini API with your API key
const genAI = new GoogleGenerativeAI(process.env.NEXT_PUBLIC_GEMINI_API_KEY || '');

const SYSTEM_PROMPT = `You are an AI assistant that helps users navigate and answer queries of a website which promotes the monetization of MCPs.`

export const generateResponse = async (prompt: string, chatHistory: Array<{role: 'user' | 'model', parts: string}>) => {
  try {
    // Get the Gemini Pro model
    const model = genAI.getGenerativeModel({ model: 'gemini-pro' });
    
    // Format chat history for the API
    const chat = model.startChat({
      history: [
        {
          role: 'user',
          parts: [{ text: SYSTEM_PROMPT }],
        },
        {
          role: 'model',
          parts: [{ text: 'I understand. I will follow these guidelines when responding to questions, especially when I don\'t have complete information.' }],
        },
        ...chatHistory.map(msg => ({
          role: msg.role === 'user' ? 'user' : 'model',
          parts: [{ text: msg.parts }],
        })),
      ],
      generationConfig: {
        maxOutputTokens: 1000,
        temperature: 0.7,
      },
    });

    // Send the message and get the response
    const result = await chat.sendMessage(prompt);
    const response = await result.response;
    const text = response.text();
    
    return {
      success: true,
      message: text,
    };
  } catch (error) {
    console.error('Error generating response:', error);
    return {
      success: false,
      message: 'Sorry, I encountered an error while processing your request. Please try again later.'
    };
  }
};

export const isQuestionUnknown = (response: string): boolean => {
  // Simple check for phrases that might indicate the model doesn't know the answer
  const unknownPhrases = [
    'i don\'t know',
    'i\'m not sure',
    'i don\'t have that information',
    'i don\'t have specific information',
    'i don\'t have access to',
    'i don\'t have the capability',
    'i don\'t have enough information',
    'i can\'t provide',
    'i\'m unable to',
    'i don\'t have the ability',
  ];

  return unknownPhrases.some(phrase => 
    response.toLowerCase().includes(phrase)
  );
};
